Filter typedef

Filter = bool Function(String tag, Map<String, String?> attributes)

Returns true if the given tag and attributes are accepted.

attributes contains all attribute names and values of the source tag.

Implementation

typedef bool Filter(String tag, Map<String, String?> attributes);