Uris class

Contains some utility functions to inspect uris.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

external(String attribute, {Iterable<String>? allowed}) Filter
Returns a Filter that can test if the path in attribute is external to all of the allowed uris.
hasAllowedScheme(String attribute, Iterable<String> schemes) Filter
Returns a Filter that can test if the path in attribute has one of the schemes.
isRelative(String uri) bool
Returns true if uri contains a relative path.
isValid(String uri) bool
Returns true if uri contains a valid uri.