Returns true if the given tag and attributes are accepted.
true
tag
attributes
attributes contains all attribute names and values of the source tag.
typedef bool Filter(String tag, Map<String, String?> attributes);